@@ -6,12 +6,9 @@ import (
 	"os"
 	"strings"
 
-	"github.com/gobuffalo/envy"
 	"github.com/gobuffalo/packr/v2/jam/store"
 )
 
-var modsOn = (strings.TrimSpace(envy.Get("GO111MODULE", "off")) == "on")
-
 //YesToAll will be used by the command to skip the questions
 var YesToAll bool
 
